# codeforces-client

Codeforces Client is a Python library and tooling for working with Codeforces.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install codeforces-client.

```bash
pip install -i https://test.pypi.org/simple/ codeforces-client
```

## Usage

```python
import codeforces_client as cf
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[gpl-3.0](LICENSE)